/* as.h - Header file for AS...

	By: Robert Seace
		120 Brainerd Road, Apt. 2
		Allston, MA  02134
		(617) 277-8835
		ras@world.std.com

	Public Domain code...  Do with it what you will...  But, PLEASE
	make note of any changes, and increment the version#, if you are
	re-distributing it...
*/

#ifndef H_AS
#define H_AS

/* Define the following only if your compiler supports/requires posix	*/
/* style function prototypes...  Used in as_proto.h to determine how	*/
/* to pre-declare the functions...										*/
#define POSIX_PROTOTYPES

/* Define the following only if your compiler supports the getopt()		*/
/* function, for parsing command-line parameters.  If you don't know,	*/
/* try it with it defined; if your compiler complains, then don't		*/
/* define it (comment it out).  The program will still work, just with	*/
/* its own, not as sophisticated, command-line parser...				*/
#define YOU_HAVE_GETOPT
extern char *optarg;
extern int optind, opterr, optopt;

/************************************************************************/
/* Comment out the following #define if you have no fnmatch() function	*/
/* in your compiler...  See below for further details...				*/
/************************************************************************/
#define FNMATCH_REAL
/************************************************************************/
/* NOTE: Only uncomment the following macro if you have no fnmatch()	*/
/* function, and can find no suitable wild-card matching function to	*/
/* replace it, and don't wish to write your own...  Understand that by	*/
/* uncommenting it, you will lose all pattern-matching abilities.  No	*/
/* wildcards will work at all; it will simply be straight, exact string	*/
/* equality testing...  This is a last-resort action, and seriously		*/
/* (IMHO, anyway) hinders the functionality of the program...			*/
/************************************************************************
#define fnmatch(p,s,f)		(strcmp (s, p))
#define FNMATCH_STRCMP
*************************************************************************/
/* Or, if you have gmatch() instead, uncomment the following line...	*/
/************************************************************************
#define fnmatch(p,s,f)		(NOT gmatch (s, p))
#define FNMATCH_GMATCH
*************************************************************************/
/* Otherwise, if you have some other, similar pattern-matching function	*/
/* that your compiler supports, that will take the place of fnmatch(),	*/
/* then #define your own replacement macro here, or manually replace	*/
/* all calls to fnmatch()...											*/
/************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <ctype.h>
#include <time.h>
#include "as_general.h"

#ifdef FNMATCH_REAL
#include <fnmatch.h>
#else
#ifdef FNMATCH_GMATCH
#include <libgen.h>
#endif
#endif


#ifndef FNM_PATHNAME	/* not already defined; for fnmatch() function */
#define FNM_PATHNAME	1
#endif


#define AS_LINE_LEN					512
#define AS_MAX_WORDS				100
#define AS_DFLT_PTBL_FILE			"as.tbl"
#define MY_BUF_LEN					80


/* main linked list of strings, codes, more nodes... */

struct as_node_struct {
	unsigned				code;				/* character number code	*/
	string					str;				/* a string					*/
	struct	as_node_struct	*str_list;			/* list of more strings		*/
	struct	as_node_struct	*prev;				/* pointer to previous node	*/
	struct	as_node_struct	*next;				/* pointer to next node		*/
};

typedef		struct as_node_struct		*as_node;

#define AS_NODE_LEN			(sizeof (struct as_node_struct))


/* linked list of strings */

struct as_str_node_struct {
	string						str;			/* a string					*/
	struct	as_str_node_struct	*prev;			/* pointer to previous node	*/
	struct	as_str_node_struct	*next;			/* pointer to next node		*/
};

typedef		struct as_str_node_struct	*as_str_node;

#define AS_STR_NODE_LEN		(sizeof (struct as_str_node_struct))


struct as_config_struct {
	as_str_node		people_names;				/* list of names of people	*/
	string			prompt_str;					/* prompt string to print	*/
	string			greeting_str;				/* greeting string to print	*/
	string			parting_str;				/* str to print when leaving*/
	as_str_node		quit_strs;					/* quit cmds to recognize	*/
};

#include "as_proto.h"

extern	struct as_config_struct	AS_Configs;
extern	as_node					AS_Head;

#endif

