/* as_general.c - Various library functions needed by AS program...
*/

#include "as.h"


/* strupper - Convert a string to all upper-case...
*/

string strupper (str)
	string	str;					/* string to capitalize					*/
{
	int		i;						/* loop counter							*/

	for (i = 0; str[i]; i++)
		str[i] = toupper (str[i]);

	return (str);
}


/* strtrim - Trims off leading and trailing spaces, newlines, tabs...
*/

string strtrim (instr)
	string	instr;					/* string to trim						*/
{
	string	str;					/* copy of string						*/
	int		i;						/* loop counter							*/

	if ((str = (string) calloc (1, strlen (instr) + 1)) IS NULL) {
		fprintf (stderr, "Not enough memory for temp copy of string (%s) to trim.\n", instr);
		exit (ERROR);
	}

	strcpy (str, instr);

	for (i = (strlen(str) - 1); i >= 0; i--) {
		if ((str[i] IS ' ') OR (str[i] IS '\n') OR (str[i] IS '\t') OR (str[i] IS '\r'))
			str[i] = '\0';
		else
			break;	/* got a non-whitespace; stop */
	}

	for (i = 0; str[i]; i++) {
		if ((str[i] ISNT ' ') AND (str[i] ISNT '\n') AND (str[i] ISNT '\t') AND (str[i] ISNT '\r'))
			break;	/* non-whitespace; stop */
	}

	strcpy (instr, &(str[i]));

	free (str);		/* free up temp string */

	return (instr);
}

/* str2array - Splits up passed string into array of substrings, separated
				by passed delimiters...
*/

void str2array (str, delims, usedelims, substrs)
	string	str;			/* string to break into substrings [MODIFIED]	*/
	string	delims;			/* list of delimiters to break string at		*/
	bool	usedelims;		/* TRUE => each char in DELIMS is a delimiter,	*/
							/* FALSE => anything NOT in DELIMS is a delim	*/
	string	substrs[];		/* array of pointers to new substrings			*/
{
	bool	insubstr;		/* TRUE => we're currently inside a substring	*/
	bool	gotdelim;		/* TRUE => we're currently at a delimiter		*/
	int		cursub;			/* index of current substring					*/
	string	dp;				/* pointer to current delimiter					*/
	string	sp;				/* temporary pointer to str						*/

	insubstr = FALSE;
	cursub = 0;

	for (sp = str; *sp; ++sp) {
		if (usedelims) {
			gotdelim = FALSE;
			for (dp = delims; *dp; ++dp) {
				if (*sp IS *dp)	{
					gotdelim = TRUE;
					break;
				}
			}
		} else {
			gotdelim = TRUE;
			for (dp = delims; *dp; ++dp) {
				if (*sp IS *dp)	{
					gotdelim = FALSE;
					break;
				}
			}
		}

		if (insubstr AND gotdelim) {
			*sp = '\0';
			insubstr = FALSE;
		} else if ((NOT insubstr) AND (NOT gotdelim)) {
			substrs[cursub++] = sp;
			insubstr = TRUE;
		}
	}

	substrs[cursub] = NULL;
}

